==> aws-cdk.aws-codepipeline-actions-1.72.0.tar.gz: package/lib/alexa-ask/deploy-action.d.ts <==
import * as codepipeline from '@aws-cdk/aws-codepipeline';
import { Construct, SecretValue } from '@aws-cdk/core';
import { Action } from '../action';
/**
 * Construction properties of the {@link AlexaSkillDeployAction Alexa deploy Action}.
 */
export interface AlexaSkillDeployActionProps extends codepipeline.CommonActionProps {
    /**
     * The client id of the developer console token.
     */
    readonly clientId: string;
    /**
     * The client secret of the developer console token.
     */
    readonly clientSecret: SecretValue;
    /**
     * The refresh token of the developer console token.
     */
    readonly refreshToken: SecretValue;
    /**
     * The Alexa skill id.
     */
    readonly skillId: string;
    /**
     * The source artifact containing the voice model and skill manifest.
     */
    readonly input: codepipeline.Artifact;
    /**
     * An optional artifact containing overrides for the skill manifest.
     */
    readonly parameterOverridesArtifact?: codepipeline.Artifact;
}
/**
 * Deploys the skill to Alexa.
 */
export declare class AlexaSkillDeployAction extends Action {
    private readonly props;
    /**
     *
     */
    constructor(props: AlexaSkillDeployActionProps);
    /**
     * The method called when an Action is attached to a Pipeline.
     *
     * This method is guaranteed to be called only once for each Action instance.
     */
    protected bound(_scope: Construct, _stage: codepipeline.IStage, _options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
}

==> aws-cdk.aws-codepipeline-actions-1.83.0.tar.gz: package/lib/alexa-ask/deploy-action.d.ts <==
import * as codepipeline from '@aws-cdk/aws-codepipeline';
import { Construct, SecretValue } from '@aws-cdk/core';
import { Action } from '../action';
/**
 * Construction properties of the {@link AlexaSkillDeployAction Alexa deploy Action}.
 *
 * @stability stable
 */
export interface AlexaSkillDeployActionProps extends codepipeline.CommonActionProps {
    /**
     * The client id of the developer console token.
     *
     * @stability stable
     */
    readonly clientId: string;
    /**
     * The client secret of the developer console token.
     *
     * @stability stable
     */
    readonly clientSecret: SecretValue;
    /**
     * The refresh token of the developer console token.
     *
     * @stability stable
     */
    readonly refreshToken: SecretValue;
    /**
     * The Alexa skill id.
     *
     * @stability stable
     */
    readonly skillId: string;
    /**
     * The source artifact containing the voice model and skill manifest.
     *
     * @stability stable
     */
    readonly input: codepipeline.Artifact;
    /**
     * An optional artifact containing overrides for the skill manifest.
     *
     * @stability stable
     */
    readonly parameterOverridesArtifact?: codepipeline.Artifact;
}
/**
 * Deploys the skill to Alexa.
 *
 * @stability stable
 */
export declare class AlexaSkillDeployAction extends Action {
    private readonly props;
    /**
     * @stability stable
     */
    constructor(props: AlexaSkillDeployActionProps);
    /**
     * The method called when an Action is attached to a Pipeline.
     *
     * This method is guaranteed to be called only once for each Action instance.
     *
     * @stability stable
     */
    protected bound(_scope: Construct, _stage: codepipeline.IStage, _options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
}
